aboutsummaryrefslogtreecommitdiffstats
path: root/engine/events/prize_menu.asm
diff options
context:
space:
mode:
authordannye <33dannye@gmail.com>2024-09-25 00:45:00 -0500
committerdannye <33dannye@gmail.com>2024-09-25 00:45:00 -0500
commita02a98ee7ada1a658e28698484058be2796dc0df (patch)
tree945986054565bd8b5212fc755415096050d1d3a8 /engine/events/prize_menu.asm
parentUse long option flags for rgbgfx, same as tools/gfx (diff)
parentUse `const_skip` (diff)
downloadpokeyellow-a02a98ee7ada1a658e28698484058be2796dc0df.tar.gz
pokeyellow-a02a98ee7ada1a658e28698484058be2796dc0df.tar.xz
pokeyellow-a02a98ee7ada1a658e28698484058be2796dc0df.zip
Merge branch 'master' of https://github.com/pret/pokered
Diffstat (limited to 'engine/events/prize_menu.asm')
-rw-r--r--engine/events/prize_menu.asm55
1 files changed, 26 insertions, 29 deletions
diff --git a/engine/events/prize_menu.asm b/engine/events/prize_menu.asm
index 47bb1062..a365f45f 100644
--- a/engine/events/prize_menu.asm
+++ b/engine/events/prize_menu.asm
@@ -5,8 +5,8 @@ CeladonPrizeMenu::
ld hl, RequireCoinCaseTextPtr
jp PrintText
.havingCoinCase
- ld hl, wd730
- set 6, [hl] ; disable letter-printing delay
+ ld hl, wStatusFlags5
+ set BIT_NO_TEXT_DELAY, [hl]
ld hl, ExchangeCoinsForPrizesTextPtr
call PrintText
; the following are the menu settings
@@ -37,8 +37,8 @@ CeladonPrizeMenu::
jr z, .noChoice
call HandlePrizeChoice
.noChoice
- ld hl, wd730
- res 6, [hl]
+ ld hl, wStatusFlags5
+ res BIT_NO_TEXT_DELAY, [hl]
ret
RequireCoinCaseTextPtr:
@@ -55,17 +55,14 @@ WhichPrizeTextPtr:
text_end
GetPrizeMenuId:
-; determine which one among the three
-; prize-texts has been selected
-; using the text ID (stored in [hSpriteIndexOrTextID])
-; load the three prizes at wd13d-wd13f
-; load the three prices at wd141-wd146
-; display the three prizes' names
-; (distinguishing between Pokemon names
-; and Items (specifically TMs) names)
- ldh a, [hSpriteIndexOrTextID]
- sub 3 ; prize-texts' id are 3, 4 and 5
- ld [wWhichPrizeWindow], a ; prize-texts' id (relative, i.e. 0, 1 or 2)
+; determine which one among the three prize texts has been selected using the text ID (stored in [hTextID])
+; prize texts' IDs are TEXT_GAMECORNERPRIZEROOM_PRIZE_VENDOR_1-TEXT_GAMECORNERPRIZEROOM_PRIZE_VENDOR_3
+; load the three prizes at wPrize1-wPrice3
+; load the three prices at wPrize1Price-wPrize3Price
+; display the three prizes' names, distinguishing between Pokemon names and item names (specifically TMs)
+ ldh a, [hTextID]
+ sub TEXT_GAMECORNERPRIZEROOM_PRIZE_VENDOR_1
+ ld [wWhichPrizeWindow], a ; prize texts' relative ID (i.e. 0-2)
add a
add a
ld d, 0
@@ -87,37 +84,37 @@ GetPrizeMenuId:
ld bc, 6
call CopyData
ld a, [wWhichPrizeWindow]
- cp 2 ;is TM_menu?
+ cp 2 ; is TM_menu?
jr nz, .putMonName
ld a, [wPrize1]
- ld [wd11e], a
+ ld [wNamedObjectIndex], a
call GetItemName
hlcoord 2, 4
call PlaceString
ld a, [wPrize2]
- ld [wd11e], a
+ ld [wNamedObjectIndex], a
call GetItemName
hlcoord 2, 6
call PlaceString
ld a, [wPrize3]
- ld [wd11e], a
+ ld [wNamedObjectIndex], a
call GetItemName
hlcoord 2, 8
call PlaceString
jr .putNoThanksText
.putMonName
ld a, [wPrize1]
- ld [wd11e], a
+ ld [wNamedObjectIndex], a
call GetMonName
hlcoord 2, 4
call PlaceString
ld a, [wPrize2]
- ld [wd11e], a
+ ld [wNamedObjectIndex], a
call GetMonName
hlcoord 2, 6
call PlaceString
ld a, [wPrize3]
- ld [wd11e], a
+ ld [wNamedObjectIndex], a
call GetMonName
hlcoord 2, 8
call PlaceString
@@ -193,7 +190,7 @@ HandlePrizeChoice:
ld hl, wPrize1
add hl, de
ld a, [hl]
- ld [wd11e], a
+ ld [wNamedObjectIndex], a
ld a, [wWhichPrizeWindow]
cp 2 ; is prize a TM?
jr nz, .getMonName
@@ -212,9 +209,9 @@ HandlePrizeChoice:
call HasEnoughCoins
jr c, .notEnoughCoins
ld a, [wWhichPrizeWindow]
- cp $02
+ cp 2 ; is prize a TM?
jr nz, .giveMon
- ld a, [wd11e]
+ ld a, [wNamedObjectIndex]
ld b, a
ld a, 1
ld c, a
@@ -222,8 +219,8 @@ HandlePrizeChoice:
jr nc, .bagFull
jr .subtractCoins
.giveMon
- ld a, [wd11e]
- ld [wcf91], a
+ ld a, [wNamedObjectIndex]
+ ld [wCurPartySpecies], a
push af
call GetPrizeMonLevel
ld c, a
@@ -288,7 +285,7 @@ OhFineThenTextPtr:
text_end
GetPrizeMonLevel:
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
ld b, a
ld hl, PrizeMonLevelDictionary
.loop
@@ -299,7 +296,7 @@ GetPrizeMonLevel:
jr .loop
.matchFound
ld a, [hl]
- ld [wCurEnemyLVL], a
+ ld [wCurEnemyLevel], a
ret
INCLUDE "data/events/prize_mon_levels.asm"